@@ -1,15 +1,26 @@
 #' Group-specific parameters of mixed models random effects
 #'
-#' Extract random parameters of each individual group in the context of mixed models. Can be reshaped to be of the same dimensions as the original data, which can be useful to add the random effects to the original data.
+#' Extract random parameters of each individual group in the context of mixed
+#' models. Can be reshaped to be of the same dimensions as the original data,
+#' which can be useful to add the random effects to the original data.
 #'
 #' @param model A mixed model with random effects.
-#' @param type If \code{"random"} (default), the coefficients are the ones estimated natively by the model (as they are returned by, for instance, \code{lme4::ranef()}). They correspond to the deviation of each individual group from their fixed effect. As such, a coefficient close to 0 means that the participants' effect is the same as the population-level effect (in other words, it is "in the norm"). If "total", it will return the sum of the random effect and its corresponding fixed effects. These are known as BLUPs (Best Linear Unbiased Predictions). This argument can be used to reproduce the results given by \code{lme4::ranef()} and \code{coef()} (see \code{?coef.merMod}). Note that BLUPs currently don't have uncertainty indices (such as SE and CI), as these are not computable.
+#' @param type If `"random"` (default), the coefficients are the ones
+#'   estimated natively by the model (as they are returned by, for instance,
+#'   `lme4::ranef()`). They correspond to the deviation of each individual
+#'   group from their fixed effect. As such, a coefficient close to 0 means that
+#'   the participants' effect is the same as the population-level effect (in
+#'   other words, it is "in the norm"). If "total", it will return the sum of
+#'   the random effect and its corresponding fixed effects. These are known as
+#'   BLUPs (Best Linear Unbiased Predictions). This argument can be used to
+#'   reproduce the results given by `lme4::ranef()` and `coef()` (see
+#'   `?coef.merMod`). Note that BLUPs currently don't have uncertainty
+#'   indices (such as SE and CI), as these are not computable.
 #' @param ... Other arguments passed to or from other methods.
 #'
 #' @examples
+#' # lme4 model
 #' if (require("lme4") && require("see")) {
-#'
-#'   # Random intercept ------------
 #'   model <- lmer(mpg ~ hp + (1 | carb), data = mtcars)
 #'   random <- estimate_grouplevel(model)
 #'   random
@@ -28,12 +39,26 @@
 #'
 #'   # Use summary() to remove duplicated rows
 #'   summary(reshaped)
+#'
+#'   # Compute BLUPs
+#'   estimate_grouplevel(model, type = "total")
+#' }
+#'
+#' # Bayesian models
+#' \donttest{
+#' if (require("rstanarm")) {
+#'   model <- rstanarm::stan_lmer(mpg ~ hp + (1 | carb), data = mtcars, refresh = 0)
+#' }
 #' }
 #' @export
 estimate_grouplevel <- function(model, type = "random", ...) {
 
   # Extract params
-  params <- parameters::model_parameters(model, group_level = TRUE, ...)
+  params <- parameters::model_parameters(model,
+    effects = "all",
+    group_level = TRUE,
+    ...
+  )
 
   # TODO: improve / add new printing that groups by group/level?
   random <- as.data.frame(params[params$Effects == "random", ])
@@ -59,7 +84,7 @@ estimate_grouplevel <- function(model, type = "random", ...) {
   random <- random[c("Group", "Level", names(random)[!names(random) %in% c("Group", "Level")])]
 
   # Sort
-  random <- random[order(random$Group, insight::to_numeric(random$Level), random$Parameter), ]
+  random <- random[order(random$Group, datawizard::to_numeric(random$Level), random$Parameter), ]
 
   # Clean
   row.names(random) <- NULL
@@ -75,4 +100,7 @@ estimate_grouplevel <- function(model, type = "random", ...) {
 }
 
 
-# TODO (maybe) summary for estimate_grouplevel: keep only coefficient column
+.estimate_grouplevel_bayesian <- function(model, type = "random", ...) {
+  param_names <- insight::clean_parameters(model)
+  posteriors <- insight::get_parameters(model, effects = "all", component = "all", ...)
+}
