@@ -1,9 +1,11 @@
 #' Easy 'emmeans' and 'emtrends'
 #'
 #' The `model_emmeans` function is a wrapper to facilitate the usage of
-#' `emmeans::emmeans()` and `emmeans::emtrends()`, providing a
-#' somewhat simpler and intuitive API to find the specifications and variables of interest.
-#' It is meanly made to for the developers to facilitate the organization and debugging, and end-users should rather use the `estimate_*` series of functions.
+#' `emmeans::emmeans()` and `emmeans::emtrends()`, providing a somewhat simpler
+#' and intuitive API to find the specifications and variables of interest. It is
+#' meanly made to for the developers to facilitate the organization and
+#' debugging, and end-users should rather use the `estimate_*` series of
+#' functions.
 #'
 #' @param model A statistical model.
 #' @param fixed A character vector indicating the names of the predictors to be
@@ -19,7 +21,10 @@
 #'   log-odds (probabilities on logit scale) and `"response"` in terms of
 #'   probabilities.
 #' @param levels,modulate Deprecated, use `at` instead.
-#' @param at The predictor variable(s) *at* which to evaluate the desired effect / mean / contrasts. Other predictors of the model that are not included here will be collapsed and "averaged" over (the effect will be estimated across them).
+#' @param at The predictor variable(s) *at* which to evaluate the desired effect
+#'   / mean / contrasts. Other predictors of the model that are not included
+#'   here will be collapsed and "averaged" over (the effect will be estimated
+#'   across them).
 #' @param ... Other arguments passed for instance to [visualisation_matrix()].
 #'
 #' @examples
@@ -90,11 +95,11 @@ model_emmeans <- function(model,
 
 #' @importFrom stats model.frame
 #' @keywords internal
-.format_emmeans_arguments <- function(model, args, ...) {
+.format_emmeans_arguments <- function(model, args, data, ...) {
 
   # Create the data_matrix
   # ---------------------------
-  data <- insight::get_data(model)
+  # data <- insight::get_data(model)
   data <- data[insight::find_predictors(model, effects = "fixed", flatten = TRUE, ...)]
 
   # Deal with 'at'
@@ -197,5 +202,5 @@ model_emmeans <- function(model,
   }
 
   args <- list(at = at, fixed = fixed)
-  .format_emmeans_arguments(model, args, ...)
+  .format_emmeans_arguments(model, args, data, ...)
 }
