@@ -3,19 +3,15 @@ if (require("testthat") && require("modelbased")) {
     model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
     estim <- estimate_means(model)
-    expect_equal(attributes(estim)$levels, "Species")
+    expect_equal(attributes(estim)$at, "Species")
     expect_equal(attributes(estim)$fixed, NULL)
-    expect_equal(attributes(estim)$modulate, NULL)
 
     estim <- estimate_means(model, fixed = "Sepal.Width")
-    expect_equal(attributes(estim)$levels, "Species")
+    expect_equal(attributes(estim)$at, "Species")
     expect_equal(attributes(estim)$fixed, "Sepal.Width")
-    expect_equal(attributes(estim)$modulate, NULL)
 
-    estim <- estimate_means(model, modulate = "Sepal.Width")
-    expect_equal(attributes(estim)$levels, "Species")
-    expect_equal(attributes(estim)$fixed, NULL)
-    expect_equal(attributes(estim)$modulate, "Sepal.Width")
+    estim <- estimate_means(model, at = "all")
+    expect_equal(attributes(estim)$at, c("Species", "Sepal.Width"))
   })
 
 
@@ -24,21 +20,17 @@ if (require("testthat") && require("modelbased")) {
     model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
     estim <- estimate_contrasts(model)
-    expect_equal(attributes(estim)$levels, "Species")
+    expect_equal(attributes(estim)$contrast, "Species")
+    expect_equal(attributes(estim)$at, NULL)
     expect_equal(attributes(estim)$fixed, NULL)
-    expect_equal(attributes(estim)$modulate, NULL)
 
-    estim <- estimate_means(model, fixed = "Sepal.Width")
-    expect_equal(attributes(estim)$levels, "Species")
+    estim <- estimate_contrasts(model, fixed = "Sepal.Width")
+    expect_equal(attributes(estim)$contrast, "Species")
     expect_equal(attributes(estim)$fixed, "Sepal.Width")
     expect_equal(attributes(estim)$modulate, NULL)
-
-    estim <- estimate_means(model, modulate = "Sepal.Width")
-    expect_equal(attributes(estim)$levels, "Species")
-    expect_equal(attributes(estim)$fixed, NULL)
-    expect_equal(attributes(estim)$modulate, "Sepal.Width")
   })
 
+
   test_that("attributes_link", {
     model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
